@@ -1495,11 +1495,11 @@ class TestOptionsFilter(CheckFilterBase):
         expr_factory = FooFilter(Person.state).new_instance().get_search_expr()
         assert callable(expr_factory)
         expr = expr_factory('foo')
-        assert str(expr) == 'persons.state IN ([POSTCOMPILE_state_1])'
+        assert str(expr) == 'persons.state IN (__[POSTCOMPILE_state_1])'
         assert expr.right.value == ['foo']
 
         expr = expr_factory('ba')
-        assert str(expr) == 'persons.state IN ([POSTCOMPILE_state_1])'
+        assert str(expr) == 'persons.state IN (__[POSTCOMPILE_state_1])'
         assert expr.right.value == ['bar', 5]
 
     def test_is(self):
@@ -1674,6 +1674,12 @@ class TestEnumArrayFilter(CheckFilterBase):
         filter.set('is', [AccountType.admin])
         self.assert_filter_query(filter, "WHERE 'admin' = ANY (array_table.account_type)")
 
+    def test_search_expression(self):
+        filter = OptionsEnumArrayFilter(
+            ents.ArrayTable.account_type, enum_type=AccountType).new_instance()
+        assert 'account_type @>' in str(filter.get_search_expr()('admin'))
+        assert filter.get_search_expr()('foo') is None
+
 
 class TestIntrospect(CheckFilterBase):
     def test_new_instance(self):
